@@ -294,7 +294,7 @@ class System(object):
 		if s.startswith("ARM-Versatile"):
 			return ("ARM", s)
 
-		v, m = s.split(maxsplit=1)
+		v, m = s.split(" ", 1)
 
 		return v, m
 
